%global majorver 3.0.1

Name:		gausssum
Version:	3.0.1.1
Release:	6%{?dist}
Summary:	A GUI application for analysis of output of quantum computations
License:	GPLv2+
URL:		http://gausssum.sourceforge.net/
Source0:	http://downloads.sourceforge.net/%{name}/GaussSum-%{version}.tar.gz
Source1:	gausssum.desktop
BuildArch:	noarch
BuildRequires:	desktop-file-utils
BuildRequires:	ImageMagick
BuildRequires:	python3-devel
Requires:	gnuplot
Requires:	python3-numpy
Requires:	python3-cclib
Requires:	python3-tkinter

%description
GaussSum is a GUI application that can analyze the output of ADF, GAMESS (US),
GAMESS-UK, Gaussian, Jaguar and PC GAMESS to extract and calculate useful
information. This includes the progress of the SCF cycles, geometry
optimization, UV-Vis/IR/Raman spectra, MO levels, MO contributions and more.

%prep
%setup -qn GaussSum-%{majorver}
# Correct the python shebang.
sed -i 's|/usr/bin/env python|%{__python3}|' GaussSum.py

# Remove the bundled cclib quotation.
for file in `find . -type f`; do
 sed -e 's|gausssum.cclib|cclib|g' $file > $file.new && \
 touch -r $file $file.new && \
 mv $file.new $file
done

# Change location of documentation.
sed 's|os\.path\.join(installlocation,"\.\.","Docs","index\.html")|"%{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}}/index.html"|g' \
 gausssum/gausssumgui.py > gausssum/gausssumgui.py.new && \
touch -r gausssum/gausssumgui.py gausssum/gausssumgui.py.new && \
mv gausssum/gausssumgui.py.new gausssum/gausssumgui.py

# Fix gnuplot location.
sed 's|os.path.join(installlocation,"gnuplot400","bin","wgnuplot.exe")|"%{_bindir}/gnuplot"|g' \
  gausssum/gausssumgui.py > gausssum/gausssumgui.py.new && \
touch -r gausssum/gausssumgui.py gausssum/gausssumgui.py.new && \
mv gausssum/gausssumgui.py.new gausssum/gausssumgui.py

# Fix end of line encodings.
for file in Docs/style.css gausssum/*.py gausssum/cclib/*.py; do
 sed -e 's|\r||g' $file > $file.new && \
 touch -r $file $file.new && \
 mv $file.new $file
done

# Fix attributes.
find gausssum/ -name "*.py" -exec chmod 644 {} + -print
chmod 644 Docs/mesh.gif Docs/style.css

# Convert icon into png.
convert GaussSum.ico GaussSum.png

# Remove integrated cclib.
rm -rf gausssum/cclib

%build
# Nothing here.

%install
mkdir -p %{buildroot}%{python3_sitelib}
# Install python library.
cp -a %{name} %{buildroot}%{python3_sitelib}
# Install python executable itself
install -pDm755 GaussSum.py %{buildroot}%{_bindir}/gausssum
# Create symlink for pedantic name.
ln -s %{_bindir}/gausssum %{buildroot}%{_bindir}/GaussSum
# Install icon.
install -pDm644 GaussSum.png %{buildroot}%{_datadir}/pixmaps/GaussSum.png
# Install desktop file.
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{S:1}

%files
%doc Docs/*
%{_bindir}/gausssum
%{_bindir}/GaussSum
%{python3_sitelib}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/GaussSum.png

%changelog
* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.1.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Feb 15 2017 Igor Gnatenko <ignatenko@redhat.com> - 3.0.1.1-5
- Rebuild for brp-python-bytecompile

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.1.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 3.0.1.1-3
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1.1-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue Mar 29 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 3.0.1.1-1
- Update to latest upstream version

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 10 2014 Christopher Meng <rpm@cicku.me> - 3.0-1
- Update to 3.0(Python 3 switch!)
- Remove binary suffix(.py -> NULL).

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Dec  6 2013 Ville Skyttä <ville.skytta@iki.fi> - 2.2.6-3
- Doc path fixes (#993766).

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Feb 18 2013 Susi Lehtola <jussilehtola@fedoraproject.org> - 2.2.6-1
- Update to 2.2.6.

* Mon Feb  4 2013 Toshio Kuratomi <toshio@fedoraproject.org> - 2.2.5-4
- Add patch for python-pillow compatibility

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Apr 25 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.5-1
- Update to 2.2.5.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Aug 6 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.4-1
- Update to 2.2.4.

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 2.2.3-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Fri Feb 19 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.3-1
- Update to 2.2.3.

* Fri Jan 1 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.2-1
- Update to 2.2.2.

* Sun Dec 27 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.0-2
- Bump release.

* Sun Dec 27 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.0-1
- Update to 2.2.0.

* Fri Jul 31 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.1.6-5
- Fix a rather nasty packaging bug, BZ #514820 arising from missing
  BR: python-devel causing library to be placed in / instead of Python library.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun May 03 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.1.6-3
- Final review fixes.

* Sun May 03 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.1.6-2
- Review fixes.

* Wed Apr 29 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.1.6-1
- First release.
